﻿using SushiBarContracts.BindingModel;
using SushiBarContracts.ViewModels;
using SushiBarDataModels;
using SushiBarDataModels.Enums;
using System.ComponentModel.DataAnnotations;
using System.Runtime.Serialization;

namespace SushiBarDatabaseImplement.Models
{
    [DataContract]
    public class Order : IOrderModel
    {
        [DataMember]
        public int Id { get; set; }

        [DataMember]
        [Required]
        public int SushiId { get; set; }

        [DataMember]
        [Required]
        public int ClientId { get; set; }

        [DataMember]
        public int? ImplementerId { get; set; }

        [DataMember]
        [Required]
        public int Count { get; set; }

        [DataMember]
        [Required]
        public double Sum { get; set; }

        [DataMember]
        [Required]
        public OrderStatus Status { get; set; } = OrderStatus.Неизвестен;

        [DataMember]
        [Required]
        public DateTime DateCreate { get; set; } = DateTime.Now;

        [DataMember]
        public DateTime? DateImplement { get; set; }

        public virtual Client? Client { get; set; }
        public virtual Implementer? Implementer { get; set; }
        public virtual Sushi? Sushi { get; set; }

        public static Order? Create(OrderBindingModel? model)
        {
            if (model == null)
            {
                return null;
            }
            return new Order()
            {
                Id = model.Id,
                SushiId = model.SushiId,
                Count = model.Count,
                Sum = model.Sum,
                Status = model.Status,
                DateCreate = model.DateCreate,
                DateImplement = model.DateImplement,
                ClientId = model.ClientId,
                ImplementerId = model.ImplementerId,
            };
        }

        public void Update(OrderBindingModel model)
        {
            if (model == null)
            {
                return;
            }
            Status = model.Status;
            DateImplement = model.DateImplement;
            ImplementerId = model.ImplementerId;
        }
        public OrderViewModel GetViewModel => new()
        {
            Id = Id,
            SushiId = SushiId,
            Count = Count,
            Sum = Sum,
            Status = Status,
            DateCreate = DateCreate,
            DateImplement = DateImplement,
            ClientId = ClientId,
            ImplementerId = ImplementerId,
            SushiName = Sushi?.SushiName ?? string.Empty,
            ClientFIO = Client?.ClientFIO ?? string.Empty,
            ImplementerFIO = Implementer?.ImplementerFIO ?? string.Empty
        };
    }
}
